==> plasma_2.0.0.tar.gz: plasma_2.0.0/core_blas/core_zssmqr.f <==
      SUBROUTINE CORE_ZSSMQR( SIDE, TRANS, M1, M2, NN, IB, K, A1, LDA1,
     $                       A2, LDA2, V, LDV, T, LDT, WORK, LDWORK,
     $                       INFO )

*********************************************************************
*     PLASMA core_blas routine (version 2.0.0)                      *
*     Release Date: July, 4th 2009                                  *
*     PLASMA is a software package provided by Univ. of Tennessee,  *
*     Univ. of California Berkeley and Univ. of Colorado Denver.    *
*********************************************************************
*
*     .. Scalar Arguments ..
      CHARACTER          SIDE, TRANS
      INTEGER            M1, M2, NN, K, IB, LDA1, LDA2, LDV, LDT
      INTEGER            LDWORK, INFO
*     ..
*     .. Array Arguments ..
      COMPLEX*16            A1( LDA1, * ), A2( LDA2, * )
      COMPLEX*16            V( LDV, * ), T( LDT, * ), WORK( * )
*     ..
*
*  Purpose
*  =======
*
*  CORE_ZSSMQR overwrites the general complex M1-by-NN tile A1 and 
*  M2-by-NN tile A2 with
*
*                      SIDE = 'L'        SIDE = 'R'
*  TRANS = 'N':         Q * | A1 |       | A1 | * Q
*                           | A2 |       | A2 |
*
*  TRANS = 'C':      Q**H * | A1 |       | A1 | * Q**H
*                           | A2 |       | A2 |
*
*  where Q is a complex unitary matrix defined as the product of k
*  elementary reflectors
*
*        Q = H(1) H(2) . . . H(k)
*
*  as returned by CORE_ZTSQRT.
*
*  Only LEFT is supported !!!
*
*  Arguments
*  =========
*
*  SIDE    (input) CHARACTER*1
*          = 'L': apply Q or Q**H from the Left;
*          = 'R': apply Q or Q**H from the Right.
*
*  TRANS   (input) CHARACTER*1
*          = 'N':  No transpose, apply Q;
*          = 'C':  ConjTranspose, apply Q**H.
*
*  M1      (input) INTEGER
*          The number of rows of the tile A1. M1 >= 0.
*
*  M2      (input) INTEGER
*          The number of rows of the tile A2. M2 >= 0.
*
*  NN      (input) INTEGER
*          The number of columns of the tiles A1 and A2. NN >= 0.
*
*  IB      (input) INTEGER
*          The inner-blocking size.  IB >= 0.
*
*  K       (input) INTEGER
*          The number of elementary reflectors whose product defines
*          the matrix Q.
*
*  A1      (input/output) COMPLEX*16 array, dimension (LDA1,M1)
*          On entry, the M1-by-NN tile A1.
*          On exit, A1 is overwritten by the application of Q.
*
*  LDA1    (input) INTEGER
*          The leading dimension of the tile A1. LDA1 >= max(1,M1).
*
*  A2      (input/output) COMPLEX*16 array, dimension (LDA2,M2)
*          On entry, the M2-by-NN tile A2.
*          On exit, A2 is overwritten by the application of Q.
*
*  LDA2    (input) INTEGER
*          The leading dimension of the tile A2. LDA2 >= max(1,M2).
*      
*  V       (input) COMPLEX*16 array, dimension (LDA,K)
*          The i-th column must contain the vector which defines the
*          elementary reflector H(i), for i = 1,2,...,k, as returned by
*          CORE_ZTSQRT in the first k columns of its array argument V.
*
*  LDV     (input) INTEGER
*          The leading dimension of the array V. LDV >= max(1,K).
*
*  T       (output) COMPLEX*16 array, dimension (LDT,NN)
*          The IB-by-NN triangular factor T of the block reflector.
*          T is upper triangular by block (economic storage);
*          The rest of the array is not referenced.
*
*  LDT     (input) INTEGER
*          The leading dimension of the array T. LDT >= IB.
*      
*  WORK    (workspace/output) COMPLEX*16 array, dimension (MAX(1,LDWORK))
*
*  LDWORK  (input) INTEGER
*          The dimension of the array WORK.
*
*  INFO    (output) INTEGER
*          = 0:  successful exit
*          < 0:  if INFO = -i, the i-th argument had an illegal value
*
*  =====================================================================
*
*     .. Local Scalars ..
      LOGICAL            LEFT, NOTRAN
      INTEGER            I, I1, I2, I3, KB, IC, IINFO, JC,
     $                   MI, NI, NQ, NW
*     ..
*     .. External Functions ..
      LOGICAL            LSAME
      EXTERNAL           LSAME
*     ..
*     .. External Subroutines ..
      EXTERNAL           CORE_ZSSRFB, XERBLA
*     ..
*     .. Intrinsic Functions ..
      INTRINSIC          MAX, MIN
*     ..
*     .. Executable Statements ..
*
*     Test the input arguments
*
      INFO = 0
      LEFT = LSAME( SIDE, 'L' )
      NOTRAN = LSAME( TRANS, 'N' )
*
*     Quick return if possible
*
      IF( M1.EQ.0 .OR. M2.EQ.0 .OR. NN.EQ.0 .OR. K.EQ.0 ) THEN
         RETURN
      END IF
*
*     NQ is the order of Q and NW is the minimum dimension of WORK
*
      IF( LEFT ) THEN
         NQ = M1
         NW = NN
      ELSE
         NQ = NN
         NW = M1
      END IF
      IF( .NOT.LEFT .AND. .NOT.LSAME( SIDE, 'R' ) ) THEN
         INFO = -1
      ELSE IF( .NOT.NOTRAN .AND. .NOT.LSAME( TRANS, 'C' ) ) THEN
         INFO = -2
      ELSE IF( M1.LT.0 ) THEN
         INFO = -3
      ELSE IF( M2.LT.0 ) THEN
         INFO = -4
      ELSE IF( NN.LT.0 ) THEN
         INFO = -5
      ELSE IF( IB.LT.0 ) THEN
         INFO = -6
      ELSE IF( K.LT.0 .OR. K.GT.NQ ) THEN
         INFO = -7
      ELSE IF( LDA1.LT.MAX( 1, NQ ) ) THEN
         INFO = -9
      END IF
*
      IF( INFO.NE.0 ) THEN
         CALL XERBLA( 'CORE_ZSSMQR', -INFO )
         RETURN
      END IF
*
      IF( ( LEFT .AND. .NOT.NOTRAN ) .OR.
     $    ( .NOT.LEFT .AND. NOTRAN ) ) THEN
         I1 = 1
         I2 = K
         I3 = IB
      ELSE
         I1 = ( ( K-1 ) / IB )*IB + 1
         I2 = 1
         I3 = -IB
      END IF
*
      IF( LEFT ) THEN
         NI = NN
         JC = 1
      ELSE
         MI = M1
         IC = 1
      END IF
*
      DO 10 I = I1, I2, I3
         KB = MIN( IB, K-I+1 )
         IF( LEFT ) THEN
*
*           H or H' is applied to C(i:m,1:n)
*
            MI = M1 - I + 1
            IC = I
         ELSE
*
*           H or H' is applied to C(1:m,i:n)
*
            NI = NN - I + 1
            JC = I
         END IF
*
*        Apply H or H'
*
         CALL CORE_ZSSRFB( SIDE, TRANS, 'Forward', 'Columnwise',
     $                    MI, M2, NI, KB, A1( IC, JC ), LDA1,
     $                    A2( 1, 1 ), LDA2,
     $                    V( 1, I ), LDV, T( 1, I ), LDT,
     $                    WORK, LDWORK, INFO )
   10 CONTINUE
      RETURN
*
*     End of CORE_ZSSMQR
*
      END

==> plasma_2.1.0.tar.gz: plasma_2.1.0/core_blas/core_zssmqr.f <==
      SUBROUTINE CORE_ZSSMQR( SIDE, TRANS, M1, M2, NN, IB, K, A1, LDA1,
     $                       A2, LDA2, V, LDV, T, LDT, WORK, LDWORK,
     $                       INFO )

*********************************************************************
*     PLASMA core_blas routine (version 2.1.0)                      *
*     Author: Hatem Ltaief                                          *
*     Release Date: November, 15th 2009                             *
*     PLASMA is a software package provided by Univ. of Tennessee,  *
*     Univ. of California Berkeley and Univ. of Colorado Denver.    *
*********************************************************************
*
*     .. Scalar Arguments ..
      CHARACTER          SIDE, TRANS
      INTEGER            M1, M2, NN, K, IB, LDA1, LDA2, LDV, LDT
      INTEGER            LDWORK, INFO
*     ..
*     .. Array Arguments ..
      COMPLEX*16            A1( LDA1, * ), A2( LDA2, * )
      COMPLEX*16            V( LDV, * ), T( LDT, * ), WORK( * )
*     ..
*
*  Purpose
*  =======
*
*  CORE_ZSSMQR overwrites the general complex M1-by-NN tile A1 and 
*  M2-by-NN tile A2 with
*
*                      SIDE = 'L'        SIDE = 'R'
*  TRANS = 'N':         Q * | A1 |       | A1 | * Q
*                           | A2 |       | A2 |
*
*  TRANS = 'C':      Q**H * | A1 |       | A1 | * Q**H
*                           | A2 |       | A2 |
*
*  where Q is a complex unitary matrix defined as the product of k
*  elementary reflectors
*
*        Q = H(1) H(2) . . . H(k)
*
*  as returned by CORE_ZTSQRT.
*
*  Only LEFT is supported !!!
*
*  Arguments
*  =========
*
*  SIDE    (input) CHARACTER*1
*          = 'L': apply Q or Q**H from the Left;
*          = 'R': apply Q or Q**H from the Right.
*
*  TRANS   (input) CHARACTER*1
*          = 'N':  No transpose, apply Q;
*          = 'C':  ConjTranspose, apply Q**H.
*
*  M1      (input) INTEGER
*          The number of rows of the tile A1. M1 >= 0.
*
*  M2      (input) INTEGER
*          The number of rows of the tile A2. M2 >= 0.
*
*  NN      (input) INTEGER
*          The number of columns of the tiles A1 and A2. NN >= 0.
*
*  IB      (input) INTEGER
*          The inner-blocking size.  IB >= 0.
*
*  K       (input) INTEGER
*          The number of elementary reflectors whose product defines
*          the matrix Q.
*
*  A1      (input/output) COMPLEX*16 array, dimension (LDA1,M1)
*          On entry, the M1-by-NN tile A1.
*          On exit, A1 is overwritten by the application of Q.
*
*  LDA1    (input) INTEGER
*          The leading dimension of the tile A1. LDA1 >= max(1,M1).
*
*  A2      (input/output) COMPLEX*16 array, dimension (LDA2,M2)
*          On entry, the M2-by-NN tile A2.
*          On exit, A2 is overwritten by the application of Q.
*
*  LDA2    (input) INTEGER
*          The leading dimension of the tile A2. LDA2 >= max(1,M2).
*
*  V       (input) COMPLEX*16 array, dimension (LDA,K)
*          The i-th column must contain the vector which defines the
*          elementary reflector H(i), for i = 1,2,...,k, as returned by
*          CORE_ZTSQRT in the first k columns of its array argument V.
*
*  LDV     (input) INTEGER
*          The leading dimension of the array V. LDV >= max(1,K).
*
*  T       (output) COMPLEX*16 array, dimension (LDT,NN)
*          The IB-by-NN triangular factor T of the block reflector.
*          T is upper triangular by block (economic storage);
*          The rest of the array is not referenced.
*
*  LDT     (input) INTEGER
*          The leading dimension of the array T. LDT >= IB.
*
*  WORK    (workspace/output) COMPLEX*16 array, dimension (MAX(1,LDWORK))
*
*  LDWORK  (input) INTEGER
*          The dimension of the array WORK.
*
*  INFO    (output) INTEGER
*          = 0:  successful exit
*          < 0:  if INFO = -i, the i-th argument had an illegal value
*
*  =====================================================================
*
*     .. Local Scalars ..
      LOGICAL            LEFT, NOTRAN
      INTEGER            I, I1, I2, I3, KB, IC, IINFO, JC,
     $                   MI, NI, NQ, NW
*     ..
*     .. External Functions ..
      LOGICAL            LSAME
      EXTERNAL           LSAME
*     ..
*     .. External Subroutines ..
      EXTERNAL           CORE_ZSSRFB, XERBLA
*     ..
*     .. Intrinsic Functions ..
      INTRINSIC          MAX, MIN
*     ..
*     .. Executable Statements ..
*
*     Test the input arguments
*
      INFO = 0
      LEFT = LSAME( SIDE, 'L' )
      NOTRAN = LSAME( TRANS, 'N' )
*
*     Quick return if possible
*
      IF( M1.EQ.0 .OR. M2.EQ.0 .OR. NN.EQ.0 .OR. K.EQ.0 ) THEN
         RETURN
      END IF
*
*     NQ is the order of Q and NW is the minimum dimension of WORK
*
      IF( LEFT ) THEN
         NQ = M1
         NW = NN
      ELSE
         NQ = NN
         NW = M1
      END IF
      IF( .NOT.LEFT .AND. .NOT.LSAME( SIDE, 'R' ) ) THEN
         INFO = -1
      ELSE IF( .NOT.NOTRAN .AND. .NOT.LSAME( TRANS, 'C' ) ) THEN
         INFO = -2
      ELSE IF( M1.LT.0 ) THEN
         INFO = -3
      ELSE IF( M2.LT.0 ) THEN
         INFO = -4
      ELSE IF( NN.LT.0 ) THEN
         INFO = -5
      ELSE IF( IB.LT.0 ) THEN
         INFO = -6
      ELSE IF( K.LT.0 .OR. K.GT.NQ ) THEN
         INFO = -7
      ELSE IF( LDA1.LT.MAX( 1, NQ ) ) THEN
         INFO = -9
      END IF
*
      IF( INFO.NE.0 ) THEN
         CALL XERBLA( 'CORE_ZSSMQR', -INFO )
         RETURN
      END IF
*
      IF( ( LEFT .AND. .NOT.NOTRAN ) .OR.
     $    ( .NOT.LEFT .AND. NOTRAN ) ) THEN
         I1 = 1
         I2 = K
         I3 = IB
      ELSE
         I1 = ( ( K-1 ) / IB )*IB + 1
         I2 = 1
         I3 = -IB
      END IF
*
      IF( LEFT ) THEN
         NI = NN
         JC = 1
      ELSE
         MI = M1
         IC = 1
      END IF
*
      DO 10 I = I1, I2, I3
         KB = MIN( IB, K-I+1 )
         IF( LEFT ) THEN
*
*           H or H' is applied to C(i:m,1:n)
*
            MI = M1 - I + 1
            IC = I
         ELSE
*
*           H or H' is applied to C(1:m,i:n)
*
            NI = NN - I + 1
            JC = I
         END IF
*
*        Apply H or H'
*
         CALL CORE_ZSSRFB( SIDE, TRANS, 'Forward', 'Columnwise',
     $                    MI, M2, NI, KB, A1( IC, JC ), LDA1,
     $                    A2( 1, 1 ), LDA2,
     $                    V( 1, I ), LDV, T( 1, I ), LDT,
     $                    WORK, LDWORK, INFO )
   10 CONTINUE
      RETURN
*
*     End of CORE_ZSSMQR
*
      END
